@@ -21,12 +21,12 @@ def notification_style(val):
 @register.filter(name='notification_status')
 def notification_status(val):
     if val:
-        return _('New')
+        return _('new').title()
     else:
-        return _('Read')
+        return _('read').title()
 
 
 @register.simple_tag(name='get_notice_count')
-def get_notice_count(request):
+def get_notice_count(user):
     """tag to display notice count"""
-    return notice_count(request)
+    return notice_count(user)
